@@ -24,7 +24,7 @@ from ceilometermiddleware.tests import base as tests_base
 from keystoneauth1.fixture import keystoneauth_betamax as betamax
 
 
-class FakeApp(object):
+class FakeApp:
     def __init__(self, body=None):
         self.body = body or ['This string is 28 bytes long']
 
@@ -36,11 +36,10 @@ class FakeApp(object):
         ])
         while env['wsgi.input'].read(5):
             pass
-        for line in self.body:
-            yield line
+        yield from self.body
 
 
-class FakeRequest(object):
+class FakeRequest:
     """A bare bones request object
 
     The middleware will inspect this for request method,
@@ -65,7 +64,7 @@ class FakeRequest(object):
 class TestSwift(tests_base.TestCase):
 
     def setUp(self):
-        super(TestSwift, self).setUp()
+        super().setUp()
         cfg.CONF([], project='ceilometermiddleware')
         self.addCleanup(cfg.CONF.reset)
 
@@ -255,13 +254,13 @@ class TestSwift(tests_base.TestCase):
             self.assertEqual('value1', metadata['http_header_x_var1'])
             self.assertEqual('value2', metadata['http_header_x_var2'])
             self.assertEqual('token', metadata['http_header_token'])
-            self.assertFalse('http_header_x_var3' in metadata)
+            self.assertNotIn('http_header_x_var3', metadata)
 
     def test_metadata_headers_unicode(self):
         app = swift.Swift(FakeApp(), {
             'metadata_headers': 'unicode'
         })
-        uni = u'\xef\xbd\xa1\xef\xbd\xa5'
+        uni = '\xef\xbd\xa1\xef\xbd\xa5'
         req = self.get_request('/1.0/account/container',
                                environ={'REQUEST_METHOD': 'GET'},
                                headers={'UNICODE': uni})
@@ -337,7 +336,7 @@ class TestSwift(tests_base.TestCase):
             data = notify.call_args_list[0][0]
             self.assertEqual("account", data[2]['target']['id'])
 
-    def test_custom_prefix(self):
+    def test_custom_reseller_prefix(self):
         app = swift.Swift(FakeApp(), {'reseller_prefix': 'CUSTOM_'})
         req = FakeRequest('/1.0/CUSTOM_account/container/obj',
                           environ={'REQUEST_METHOD': 'GET'})
@@ -347,6 +346,16 @@ class TestSwift(tests_base.TestCase):
             data = notify.call_args_list[0][0]
             self.assertEqual("account", data[2]['target']['id'])
 
+    def test_empty_reseller_prefix(self):
+        app = swift.Swift(FakeApp(), {'reseller_prefix': ''})
+        req = FakeRequest('/1.0/account/container/obj',
+                          environ={'REQUEST_METHOD': 'GET'})
+        with mock.patch('oslo_messaging.Notifier.info') as notify:
+            list(app(req.environ, self.start_response))
+            self.assertEqual(1, len(notify.call_args_list))
+            data = notify.call_args_list[0][0]
+            self.assertEqual("account", data[2]['target']['id'])
+
     def test_incomplete_reseller_prefix(self):
         # Custom reseller prefix set, but without trailing underscore
         app = swift.Swift(
@@ -397,7 +406,7 @@ class TestSwift(tests_base.TestCase):
                 list(app(req.environ, self.start_response))
                 self.assertEqual(calls, len(notify.call_args_list))
 
-    def test_empty_reseller_prefix(self):
+    def test_only_reseller_prefix(self):
         app = swift.Swift(
             FakeApp(), {'reseller_prefix': 'CUSTOM'})
         req = FakeRequest('/1.0/CUSTOM/container/obj',
